OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} მომხმარებელმა შეცვალა თქვენი პაროლი",
    "You changed your password" : "თქვენ შეცვალეთ თქვენი პაროლი",
    "Your password was reset by an administrator" : "თქვენი პაროლი ადმინისტრატორმა აღადგინა",
    "{actor} changed your email address" : "{actor} მომხმარებელმა შეცვალა თქვენი ელ-ფოსტის მისამართი",
    "You changed your email address" : "თქვენ შეცვალეთ თქვენი ელ-ფოსტის მისამართი",
    "Your email address was changed by an administrator" : "თქვენი ელ-ფოსტის მისამართი ადმინისტრატორის მიერ შეიცვალა",
    "Security" : "უსაფრთხოება",
    "You successfully logged in using two-factor authentication (%1$s)" : "თქვენ ორ-ფაქტორიანი აუტენტიფიკაციით წარმატებით გაიარეთ ავტორიზაცია (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "ავტორიზაცია ორ-ფაქტორიანი აუტენტიფიკაციით ვერ მოხერხდა (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>თქვენი პაროლი</strong> ან <strong>ელ-ფოსტის მისამართი</strong> შეიცვალა",
    "Settings" : "პარამეტრები",
    "Wrong password" : "არასწორი პაროლი",
    "Saved" : "დამახსოვრდა",
    "Unable to change password" : "პაროლის ცვილება შეუძლებელია",
    "Authentication error" : "აუტენტიფიკაციის შეცდომა",
    "Wrong admin recovery password. Please check the password and try again." : "ადმინისტრატორის აღდგენის არასწორი პაროლი. გთხოვთ გადაამოწმოთ პაროლი და სცადოთ ახლიდან.",
    "Administrator documentation" : "ადმინისტრატორის დოკუმენტაცია",
    "User documentation" : "მომხმარებლის დოკუმენტაცია",
    "Invalid SMTP password." : "არასწორი SMTP პაროლი.",
    "Email setting test" : "ელ-ფოსტის დაყენების შემოწმება",
    "Well done, %s!" : "ყველაფერი კარგადაა, %s!",
    "If you received this email, the email configuration seems to be correct." : "იმ შემთხვევაში თუ მიიღეთ ეს ელ-წერილი, ელ-ფოსტის კონფიგურაცია კარგად უნდა იყოს.",
    "Email could not be sent. Check your mail server log" : "ელ-წერილი ვერ იგზავნება. გთხოვთ შეამოწმოთ მეილ-სერვერის ლოგი",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ელ-წერილის გაგზავნისას წარმოიშვა შეცდომა. გთხოვთ გადახედოთ თქვენს პარამეტრებს. (შეცდომა: %s)",
    "Invalid account" : "არასწორი ანგარიში",
    "Invalid mail address" : "არასწორი საფოსტო მისამართი",
    "Settings saved" : "პარამეტრები შენახულია",
    "Unable to change full name" : "სრული სახელის ცვლილება ვერ ხერხდება",
    "Unable to change email address" : "ელ-ფოსტის მისამართი ვერ იცვლება",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "თქვენი Twitter-ის ანგარიშის დასამოწმებლად, Twitter-ზე დაპოსტეთ შემდეგი (მიაქციათ ყურადღება რომ პოსტავთ ხაზის წყვეტის გარეშე): ",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "თქვენი საიტის დასამოწმებლად, შემდეგი მოცულობა მოათავსეთ web-root-ში '.well-known/CloudIdVerificationCode.txt' ადგილას (დარწმუნდით რომ მთელი ტექსტი ერთ ხაზზეა): ",
    "%1$s changed your password on %2$s." : "%1$s მომხმარებელმა თქვენი პაროლი შეცვალა %2$s-ზე.",
    "Your password on %s was changed." : "თქვენი პაროლი %s-ზე შეიცვალა.",
    "Your password on %s was reset by an administrator." : "თქვენი პაროლი %s-ზე ადმინისტრატორმა აღადგინა.",
    "Password for %1$s changed on %2$s" : "პაროლი %1$s-სთვის შეიცვალა %2$s-ზე",
    "Password changed for %s" : "პაროლი %s-სთვის შეიცვალა",
    "If you did not request this, please contact an administrator." : "თუ ეს არ მოგითხოვიათ, მიმართეთ ადმინისტრატორს",
    "Your email address on %s was changed." : "თქვენი ელ-ფოსტის მისამართი %s-ზე შეიცვალა.",
    "Your email address on %s was changed by an administrator." : "თქვენი ელ-ფოსტის მისამართი %s-ზე ადმინისტრატორმა შეცვალა.",
    "Email address for %1$s changed on %2$s" : "ელ-ფოსტის მისამართი %1$s-სთვის შეიცვალა %2$s-ზე",
    "Email address changed for %s" : "ელ-ფოსტის მისამართი %s-სთვის შეიცვალა",
    "The new email address is %s" : "ახალი ელ-ფოსტის მისამართია %s",
    "Your %s account was created" : "თქვენი %s ანგარიში შექმნილია",
    "Welcome aboard" : "კეთილი იყოს თქვენი ბორტზე მობრძანება",
    "Welcome aboard %s" : "%s, კეთილი იყოს თქვენი ბორტზე მობრძანება",
    "Welcome to your %s account, you can add, protect, and share your data." : "კეთილი იყოს თქვენი %s ანგარიშში მობრძანება, შეგიძლიათ დაამატოთ, დაიცვათ და გააზიაროთ თქვენი მონაცემები.",
    "Set your password" : "დააყენეთ თქვენი პაროლი",
    "Go to %s" : "გადადით %s-ზე",
    "Install Client" : "დააყენეთ კლიენტი",
    "Apps" : "აპლიკაციები",
    "Personal" : "პირადი",
    "Administration" : "ადმინისტრაცია",
    "Users" : "მომხმარებლები",
    "Additional settings" : "დამატებითი პარამეტრები",
    "Overview" : "ზოგადი მიმოხილვა",
    "Basic settings" : "ძირითადი პარამეტრები",
    "Sharing" : "გაზიარება",
    "Calendar" : "კალენდარი",
    "Personal info" : "პირადი ინფორმაცია",
    "Mobile & desktop" : "მობილური და დესკტოპი",
    "Email server" : "საფოსტო სერვერი",
    "Background jobs" : "ფონური საქმეები",
    "Unlimited" : "ულიმიტო",
    "Verifying" : "მოწმდება",
    "Verifying …" : "მოწმდება …",
    "Verify" : "დამოწმება",
    "Disabled" : "არაა მოქმედი",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-ს ფუნქცია \"set_time_limit\" არაა ხელმისაწვდომი. ამან შეიძლება ქმედებისას გამოიწვიოს სკრიპტების შეჩერება, ინსტალაციის შეწყვეტა. რეკომენდირებულია ამ ფუნქციის ჩართვა.",
    "Supported" : "მხარდაჭერილია",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "თქვენს PHP-ს არ აქვს FreeType-ის მხარდაჭერა, რაც გამოწვევს დარღვეულ პროფილის სურათებს და პარამეტრების ინტერფეისს.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "როგორც ჩანს PHP სისტემის გარემოს ცვლადების მიღებისთვის არაა სწორად მოწყობილი. ეს ტესტი getenv(\"PATH\")-ით აბრუნებს მხოლოდ ცარიელ პასუხს.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "თქვენი მონაცემთა ბაზა არ მოქმედებს \"READ COMMITTED\" ტრანზაქციის იზოლაციის დონით. ამან შეიძლება გამოიწვიოს პრობლემა, როდესაც მრავალი ქმედება შესრულდება პარალელურად.",
    "Enable" : "ჩართვა",
    "None" : "არც ერთი",
    "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
    "Allow resharing" : "ხელახალი გაზიარების დაშვება",
    "Allow sharing with groups" : "ჯგუფებთან გაზიარების მხარდაჭერა",
    "Restrict users to only share with users in their groups" : "შეზღუდეთ მომხმარებლები გააზიარონ მომხმარებლებთან, რომლებიც მიეკუთვნებიან მათ ჯგუფებს",
    "Allow public uploads" : "საქვეყნო ატვირთების დაშვება",
    "Always ask for a password" : "ყოველთვის მოხდეს პაროლის მოთხოვნა",
    "Enforce password protection" : "პროლით დაცვის იძულება",
    "Enforce expiration date" : "ვადის ამოწურვის თარიღის იძულება",
    "This text will be shown on the public link upload page when the file list is hidden." : "ეს ტექსტი გამოჩნდება ღია ბმულის ატვირთვის გვერდზე, როდესაც ფაილების სია დამალულია.",
    "Default share permissions" : "საწყისი გაზიარების პარამეტრები",
    "Limit to groups" : "ლიმიტი ჯგუფებზე",
    "Save changes" : "ცვილებების შენახვა",
    "Default" : "საწყისი პარამეტრები",
    "Remove" : "წაშლა",
    "Featured" : "გამორჩეულები",
    "Icon" : "პიქტოგრამა",
    "Name" : "სახელი",
    "Version" : "ვერსია",
    "Level" : "დონე",
    "Actions" : "მოქმედებები",
    "No apps found for your version" : "აპლიკაციები თქვენი ვერსიისთვის ვერ იქნა ნაპოვნი",
    "Groups" : "ჯგუფები",
    "Group name" : "ჯგუფის სახელი",
    "Daemon" : "დაემონი",
    "Display Name" : "დისპლეი სახელი",
    "Learn more" : "შეიტყვეთ მეტი",
    "Confirm" : "დადასტურება",
    "Cancel" : "უარყოფა",
    "Description" : "აღწერილობა",
    "View in store" : "იხილეთ store-ში",
    "Visit website" : "საიტზე სტუმრობა",
    "Admin documentation" : "ადმინისტრატორის დოკუმენტაცია",
    "Developer documentation" : "დეველოპერის დოკუმენტაცია",
    "Details" : "დეტალები",
    "All" : "ყველა",
    "No results" : "შედეგები არაა",
    "Update to {version}" : "განაახლეთ ვერსიაზე {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "ეს აპლიკაცია ვერ დაყენდა რადგან შემდეგი დამოკიდებულებები არაა დაკმაყოფილებული:",
    "Categories" : "კატეგორიები",
    "Resources" : "რესურსები",
    "Documentation" : "დოკუმენტაცია",
    "Report a bug" : "განაცხადეთ შეცდომის შესახებ",
    "Request feature" : "მოითხოვეთ ფუნქცია",
    "Ask questions or discuss" : "იკითხეთ ან განიხილეთ",
    "Rate" : "შეაფასეთ",
    "Changelog" : "ცვლილებების ლოგი",
    "Google Chrome for Android" : "Google Chrome Android-ისთვის",
    "{productName} Android app" : "{productName} Android აპლიკაცია",
    "This session" : "ეს სესია",
    "Allow filesystem access" : "ფაილ-სისტემაზე წვდომის მინიჭება",
    "Rename" : "სახელის შეცვლა",
    "Revoke" : "წვდომის გაუქმება",
    "Device" : "მოწყობილობა",
    "Last activity" : "ბოლო აქტივობა",
    "Web, desktop and mobile clients currently logged in to your account." : "ვებ, დესკტოპ და მობილური კლიენტები ამჟამად ავტორიზირებული თქვენს ანგარიშზე.",
    "Error while creating device token" : "მოწყობილობის ტოკენის ჩატვირთვისას წარმოიქმნა შეცდომა",
    "App name" : "აპლიკაციის სახელი",
    "Create new app password" : "ახალი აპლიკაციის პაროლის შექმნა",
    "Login" : "ლოგინი",
    "Password" : "პაროლი",
    "Password confirmation is required" : "საჭიროა პაროლის დამოწმება",
    "Server-side encryption" : "სერვერული-მხარის შიფრაცია",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "სერვერული-მხარის შიფრაცია იძლევა სერვერზე ატვირთული ფაილების შიფრაციის საშუალებას. ეს ფუნქცია ლიმიტს აწესებს მოქმედებაზე, ასე რომ გააქტიურედ მხოლოდ აუცილებლობისას.",
    "Enable server-side encryption" : "სერვერული-მხარის შიფრაციის ამოქმედება",
    "No encryption module loaded, please enable an encryption module in the app menu." : "შიფრაციის მოდული არაა ჩატვირთული, გთხოვთ აამოქმედოთ ის აპლიკაციის მენიუდან. ",
    "Select default encryption module:" : "აირჩიეთ შიფრაციის საწყისი მოდული:",
    "Enable encryption" : "შიფრაციის ამოქმედება",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "შიფრაციის ჩართვის შემდეგ, სერვერზე ატვირთული ყველა ფაილი დაიშიფრება. იმ შემთხვევაში თუ აქტიური შიფრაციის მოდულს აქვს შიფრაციის დეაქტივაციის უნარი და ყველა წინაპირობა დაცულია (მაგ.: აღდგენის გასაღების დაყენება), სხვა დროს შეძლებთ მისი მოქმედების შეჩერებას.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "მხოლოდ შიფრაცია არ იძლევა სისტემის უსაფრთხოების გარანტიას. მეტი ინფორმაციისთვის იმაზე თუ როგორ მუშაობს შიფრაციის აპლიკაცია იხილეთ დოკუმენტაცია და გაეცანით მოხმარების შემთხვევებს.",
    "Be aware that encryption always increases the file size." : "იცოდეთ, შიფრაცია ყოველთვის ზრდის ფაილის ზომას.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "ყოველთვის კარგია თქვენი მონაცემების დაზღვევა, შიფრაციის შემთხვევაში თვენს მონაცემებთან ერთად აუცილებლად დააზღვიეთ შიფრაციის გასაღებებიც.",
    "This is the final warning: Do you really want to enable encryption?" : "ეს ბოლო გაფრთხილებაა: ნამდვილად გსურთ შიფრაციის ამოქმედება?",
    "Submit" : "გაგზავნა",
    "Current password" : "ამჟამინდელი პაროლი",
    "New password" : "ახალი პაროლი",
    "Picture provided by original account" : "სურათი ორიგინალი ანგარიშიდან",
    "No email address set" : "ელ-ფოსტის მისამართი არაა დაყენებული",
    "Help translate" : "თარგმნის დახმარება",
    "Your phone number" : "თქვენი ტელეფონის ნომერი",
    "Your website" : "თქვენი ვებ-საიტი",
    "Change" : "შეცვლა",
    "Delete" : "წაშლა",
    "Email" : "ელ-ფოსტა",
    "Quota" : "ქვოტა",
    "Language" : "ენა",
    "Avatar" : "ავატარი",
    "Group admin for" : "ადმინისტრატორის შეჯგუფება",
    "Storage location" : "საცავის ადგილმდებარეობა",
    "Last login" : "ბოლო ავტორიზაცია",
    "Account actions" : "ანგარიშის ქმედებები",
    "{size} used" : "მოხმარებულია {size}",
    "Delete account" : "ანგარიშის გაუქმება",
    "Done" : "დასრულდა",
    "Edit" : "შეცვლა",
    "Show last login" : "ბოლო ავტორიზაციის ჩვენება",
    "Send email" : "ელ-წერილის გაგზავნა",
    "Default quota" : "საწყისი კვოტა",
    "Unnamed device" : "უსახელო მოწყობილობა",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "ამ სერვერის მოწყობა ელ-წერილების გასაგზვნად მნიშვნელოვანია, მაგ. პაროლის აღსადგენად და შეტყობინებების მისაღებად.",
    "Send mode" : "გაგზავნის რეჟიმი",
    "Encryption" : "შიფრაცია",
    "From address" : "მისამართიდან",
    "Domain" : "დომენი",
    "Server address" : "სერვერის მისამართი",
    "Host" : "ჰოსტი",
    "Port" : "პორტი",
    "Authentication" : "აუტენტიფიკაცია",
    "Authentication required" : "აუტენტიფიკაცია საჭიროებს",
    "Saving…" : "მიმდინარეობს დამახსოვრება...",
    "Save settings" : "პარამეტრების შენახვა",
    "Security & setup warnings" : "უსაფრთხოების და მოწყობის გაფრთხილებები",
    "Try again" : "სცადეთ ახლიდან",
    "All checks passed." : "ყველა შემოწმებამ ჩაიარა დადებითად.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "როგორც ადმინისტრატორს შეგიძლიათ გაზიარების ქცევის კორექტირება. დამატებითი ინფორმაციისთვის იხილეთ დოკუმენტაცია.",
    "Apply" : "გამოყენება",
    "Admins" : "ადმინისტრატორები",
    "Location" : "ადგილმდებარეობა",
    "Profile picture" : "პროფილის სურათი",
    "About" : "შესახებ",
    "Full name" : "სრული სახელი",
    "Phone number" : "ტელეფონის ნომერი",
    "Website" : "ვებ-საიტი",
    "Private" : "პირადი",
    "Local" : "ლოკალური",
    "Federated" : "ფედერალური",
    "Your apps" : "თქვენი აპლიკაციები",
    "Disabled apps" : "არამოქმედი აპლიკაციები",
    "Updates" : "განახლებები",
    "App bundles" : "აპლიკაციის შეკვრები",
    "Hide" : "დამალვა",
    "Disable" : "გამორთვა",
    "Unknown" : "უცნობია",
    "Never" : "არასდროს",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "აპლიკაცია ამოქმედდა, თუმცა საჭიროებს განახლებას. 5 წამში გადამისამართდებით განახლების გვერდზე.",
    "Error" : "შეცდომა",
    "Forum" : "ფორუმი",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "განავითარა {communityopen}Nextcloud საზოგადოებამ{linkclose}, {githubopen}კოდი{linkclose} is ლიცენზირებულია {licenseopen}AGPL ლიცენზიით{linkclose}.",
    "Like our Facebook page" : "მოიწონეთ ჩვენი Facebook გვერდი",
    "Check out our blog" : "იხილეთ ჩვენი ბლოგი",
    "Subscribe to our newsletter" : "გამოიწერეთ ჩვენი სიახლეები",
    "Open documentation" : "ღია დოკუმენტაცია",
    "Very weak password" : "ძალიან სუსტი პაროლი",
    "Weak password" : "სუსტი პაროლი",
    "So-so password" : "ნორმალური პაროლი",
    "Good password" : "კარგი პაროლი",
    "Strong password" : "ძლიერი პაროლ",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მინიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მაქსიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
    "Sending…" : "იგზავნება…",
    "Email sent" : "ელ-წერილი გაიგზავნა",
    "SSL" : "SSL",
    "Credentials" : "უფლებამოსილებანი",
    "SMTP Password" : "SMTP მომხმარებლის პაროლი",
    "Save" : "შენახვა"
},
"nplurals=2; plural=(n!=1);");
